Skip to contents

Creates an R Markdown report with summary statistics for each table in fg_bq_tables

Usage

fg_register_data_summaries(
  fg_bq_tables,
  output_path = NULL,
  detailedOutput = FALSE
)

Arguments

fg_bq_tables

An fg_bq_tables object

output_path

Path where the R Markdown file will be written. If NULL, creates a temp file, renders to HTML, and opens in browser.

detailedOutput

Logical flag to include detailed column-level statistics (default: FALSE)

Value

The path to the generated R Markdown file (invisibly)